@@ -1,7 +1,10 @@
 use crate::types::Doc;
 
 pub fn format(results: Vec<Doc>, output_format: &str) -> Vec<String> {
-    debug!("Going to format the following results with format '{:?}':\n{:?}", output_format, &results);
+    debug!(
+        "Going to format the following results with format '{:?}':\n{:?}",
+        output_format, &results
+    );
 
     match output_format {
         "gradle" => gradle(results),
@@ -32,7 +35,7 @@ fn transform<F>(results: Vec<Doc>, func: F) -> Vec<String>
 where
     F: Fn(&Doc) -> String,
 {
-    results.iter().map(|doc| func(doc)).collect()
+    results.iter().map(func).collect()
 }
 
 fn maven(results: Vec<Doc>) -> Vec<String> {
