@@ -3,8 +3,9 @@ use serde::Deserialize;
 #[derive(Debug)]
 pub enum MavenError<'a> {
     Args(getargs::Error<'a>),
-    Http(reqwest::Error),
+    Http(ureq::Error),
     Json(serde_json::Error),
+    IO(std::io::Error),
 }
 
 impl<'a> From<getargs::Error<'a>> for MavenError<'a> {
@@ -13,8 +14,8 @@ impl<'a> From<getargs::Error<'a>> for MavenError<'a> {
     }
 }
 
-impl<'a> From<reqwest::Error> for MavenError<'a> {
-    fn from(err: reqwest::Error) -> Self {
+impl<'a> From<ureq::Error> for MavenError<'a> {
+    fn from(err: ureq::Error) -> Self {
         MavenError::Http(err)
     }
 }
@@ -25,9 +26,15 @@ impl<'a> From<serde_json::Error> for MavenError<'a> {
     }
 }
 
+impl<'a> From<std::io::Error> for MavenError<'a> {
+    fn from(err: std::io::Error) -> Self {
+        MavenError::IO(err)
+    }
+}
+
 pub type MavenResult<'a, T> = Result<T, MavenError<'a>>;
 
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Default)]
 pub struct MavenSearchArgs<'a> {
     pub show_version: bool,
     pub show_help: bool,
@@ -36,18 +43,6 @@ pub struct MavenSearchArgs<'a> {
     pub check_for_update: bool,
 }
 
-impl<'a> Default for MavenSearchArgs<'a> {
-    fn default() -> Self {
-        MavenSearchArgs {
-            show_version: false,
-            show_help: false,
-            format: "",
-            search_term: None,
-            check_for_update: false,
-        }
-    }
-}
-
 #[derive(Debug, Deserialize)]
 #[allow(non_snake_case)]
 pub struct Doc {
